import QtQuick 2.0
import Sailfish.Silica 1.0
import harbour.orn 1.0
import "../components"

Page {
    property OrnBookmarksModel model

    id: page
    allowedOrientations: defaultAllowedOrientations

    Connections {
        target: model
        onRowsInserted: proxyModel.sort(Qt.AscendingOrder)
    }

    SilicaListView {
        id: bookmarksList
        anchors.fill: parent
        model: OrnProxyModel {
            id: proxyModel
            sortRole: OrnBookmarksModel.SortRole
            sortCaseSensitivity: Qt.CaseInsensitive
            sourceModel: page.model
        }

        header: PageHeader {
            //% "Bookmarks"
            title: qsTrId("orn-bookmarks")
        }

        section {
            property: "title"
            criteria: ViewSection.FirstCharacter
            delegate: SectionHeader {
                text: section.toUpperCase()
            }
        }

        delegate: AppListDelegate {}

        PullDownMenu {
            id: menu

            RefreshMenuItem {
                model: page.model
            }

            MenuSearchItem {}

            MenuStatusLabel {}
        }

        VerticalScrollDecorator {}

        BusyIndicator {
            size: BusyIndicatorSize.Large
            anchors.centerIn: parent
            running: page.model.fetching
        }

        ViewPlaceholder {
            enabled: !page.model.fetching && bookmarksList.count === 0
            //% "Your bookmarked applications will be shown here"
            text: qsTrId("orn-no-bookmarks")
        }
    }
}
